@@ -4,7 +4,6 @@ use strict;
 use warnings;
 use Foorum::Version; our $VERSION = $Foorum::VERSION;
 use base 'Catalyst::Controller';
-use Foorum::Utils qw/generate_random_word/;
 use Foorum::XUtils qw/theschwartz/;
 use Digest ();
 use Locale::Country::Multilingual;
@@ -108,23 +107,52 @@ sub edit : Local {
 }
 
 sub change_password : Local {
-    my ( $self, $c ) = @_;
-
-    return $c->res->redirect('/login') unless ( $c->user_exists );
+    my ( $self, $c, $username, $security_code ) = @_;
 
+    my $password = $c->req->param('password');
     $c->stash->{template} = 'user/profile/change_password.html';
 
-    return unless ( $c->req->method eq 'POST' );
+    my $user;
 
-    # check the password typed in is correct
-    my $password = $c->req->param('password');
-    my $d = Digest->new( $c->config->{authentication}->{password_hash_type} );
-    $d->add($password);
-    my $computed = $d->digest;
-    if ( $computed ne $c->user->{password} ) {
-        $c->set_invalid_form( password => 'WRONG_PASSWORD' );
-        return;
+    # the user input old password
+    # or the user click from forget_password email
+    # CAN change password
+    my $can_change_password = 0;
+    if ( $username and $security_code ) {
+
+        # check if that's mataches.
+        $user = $c->model('User')->get( { username => $username } );
+        if ($user) {
+            my $security_code2 = $c->model('DBIC::SecurityCode')
+                ->get( 'forget_password', $user->{user_id} );
+            if ( $security_code2 and $security_code2 eq $security_code ) {
+                $can_change_password = 1;
+                $c->stash->{use_security_code} = 1;
+            }
+        }
+        $c->stash->{user} = $user;
     }
+    unless ($can_change_password) {
+        return $c->res->redirect('/login') unless ( $c->user_exists );
+        $user = $c->user;
+        $c->stash->{user} = $user;
+
+        # check the password typed in is correct
+        if ($password) {
+            my $d = Digest->new(
+                $c->config->{authentication}->{password_hash_type} );
+            $d->add($password);
+            my $computed = $d->digest;
+            if ( $computed ne $c->user->{password} ) {
+                $c->set_invalid_form( password => 'WRONG_PASSWORD' );
+                $c->stash->{user} = $user;
+                return;
+            }
+            $can_change_password = 1;
+        }
+    }
+
+    return unless ($can_change_password);
 
     # execute validation.
     $c->form(
@@ -136,16 +164,23 @@ sub change_password : Local {
 
     # encrypted the new password
     my $new_password = $c->req->param('new_password');
+    my $d = Digest->new( $c->config->{authentication}->{password_hash_type} );
     $d->reset;
     $d->add($new_password);
     my $new_computed = $d->digest;
 
     $c->model('DBIC::User')
-        ->update_user( $c->user, { password => $new_computed, } );
+        ->update_user( $user, { password => $new_computed } );
+
+    # delete so that can't use again
+    if ( $c->stash->{use_security_code} ) {
+        $c->model('DBIC::SecurityCode')
+            ->remove( 'forget_password', $user->{user_id} );
+    }
 
     $c->detach(
         '/print_message',
-        [   {   msg          => 'OK',
+        [   {   msg          => 'Reset Password OK',
                 url          => '/profile/edit',
                 stay_in_page => 1,
             }
@@ -162,15 +197,23 @@ sub forget_password : Local {
     my $username = $c->req->param('username');
     my $email    = $c->req->param('email');
 
-    my $user = $c->model('DBIC::User')->get( { username => $username } );
-    return $c->stash->{ERROR_NOT_SUCH_USER} = 1 unless ($user);
-    return $c->stash->{ERROR_NOT_MATCH} = 1 if ( $user->{email} ne $email );
+    my $user;
+    if ($username) {
+        $user = $c->model('DBIC::User')->get( { username => $username } );
+        return $c->stash->{ERROR_NOT_SUCH_USER} = 1 unless ($user);
+        $email = $user->{email};
+    } elsif ($email) {
+        $user = $c->model('DBIC::User')->get( { email => $email } );
+        return $c->stash->{ERROR_NOT_SUCH_EMAIL} = 1 unless ($user);
+        $username = $user->{username};
+    } else {
+        return;
+    }
 
-    # create a random password
-    my $random_password = &generate_random_word(8);
-    my $d = Digest->new( $c->config->{authentication}->{password_hash_type} );
-    $d->add($random_password);
-    my $computed = $d->digest;
+    # create a security code
+    # URL contains the security_code can change his password later
+    my $security_code = $c->model('DBIC::SecurityCode')
+        ->get_or_create( 'forget_password', $user->{user_id} );
 
     # send email
     $c->model('DBIC::ScheduledEmail')->create_email(
@@ -178,17 +221,17 @@ sub forget_password : Local {
             to       => $email,
             lang     => $c->stash->{lang},
             stash    => {
-                username => $username,
-                password => $random_password
+                username      => $username,
+                security_code => $security_code,
+                IP            => $c->req->address,
             }
         }
     );
-    $c->model('DBIC::User')->update_user( $user, { password => $computed } );
     $c->detach(
         '/print_message',
         [   {   msg =>
-                    'Your Password is Sent to Your Email, Please have a check',
-                url          => '/login?username=' . $user->{username},
+                    'The instruction to rest your password is sent to your email, please have a check',
+                url          => '/',
                 stay_in_page => 1,
             }
         ]
