@@ -11,7 +11,8 @@ sub remove_from_db {
     my $schema = $self->result_source->schema;
 
     $self->search( { message_id => $message_id } )->delete;
-    $schema->resultset('MessageUnread')->search( { message_id => $message_id } )->delete;
+    $schema->resultset('MessageUnread')
+        ->search( { message_id => $message_id } )->delete;
 }
 
 sub are_messages_unread {
@@ -45,8 +46,10 @@ sub get_unread_cnt {
     if ($cacheval) {
         return $cacheval->{val};
     } else {
-        my $cnt = $schema->resultset('MessageUnread')->count( { user_id => $user_id } );
-        $cache->set( $cachekey, { val => $cnt, 1 => 2 }, 1800 );    # half an hour
+        my $cnt = $schema->resultset('MessageUnread')
+            ->count( { user_id => $user_id } );
+        $cache->set( $cachekey, { val => $cnt, 1 => 2 }, 1800 )
+            ;    # half an hour
 
         return $cnt;
     }
