@@ -78,8 +78,8 @@ sub remove_by_upload {
     my $directory_1 = int( $upload->{upload_id} / 3200 / 3200 );
     my $directory_2 = int( $upload->{upload_id} / 3200 );
     my $file
-        = File::Spec->catfile( $base_path, 'root', 'upload', $directory_1, $directory_2,
-        $upload->{filename} );
+        = File::Spec->catfile( $base_path, 'root', 'upload', $directory_1,
+        $directory_2, $upload->{filename} );
     remove($file);
     $self->search( { upload_id => $upload->{upload_id} } )->delete;
 
@@ -102,14 +102,16 @@ sub add_file {
     }
     ($filesize) = ( $filesize =~ /^(\d+\.?\d{0,1})/ );    # float(6,1)
 
-    my ( $filename_no_postfix, $filetype ) = ( $basename =~ /^(.*?)\.(\w+)$/ );
+    my ( $filename_no_postfix, $filetype )
+        = ( $basename =~ /^(.*?)\.(\w+)$/ );
     $filetype = lc($filetype);
     unless ( grep { $filetype eq $_ } @valid_types ) {
         return 'UNSUPPORTED_FILETYPE';
     }
 
     if ( length($filename_no_postfix) > 30 ) {
-        $filename_no_postfix = substr( $filename_no_postfix, 0, 30 );    # varchar(36)
+        $filename_no_postfix
+            = substr( $filename_no_postfix, 0, 30 );      # varchar(36)
         $basename = $filename_no_postfix . ".$filetype";
     }
     my $upload_rs = $self->create(
@@ -126,29 +128,31 @@ sub add_file {
     my $directory_1 = int( $upload_id / 3200 / 3200 );
     my $directory_2 = int( $upload_id / 3200 );
     my $upload_dir
-        = File::Spec->catdir( $base_path, 'root', 'upload', $directory_1, $directory_2 );
+        = File::Spec->catdir( $base_path, 'root', 'upload', $directory_1,
+        $directory_2 );
 
     unless ( -e $upload_dir ) {
-        my @created
-            = mkpath( [$upload_dir], 0, 0777 );    ## no critic (ProhibitLeadingZeros)
-               # copy index.html to protect dir from Options Indexes
-        my $indexfile = File::Spec->catfile( $base_path, 'root', 'upload', 'index.html' );
+        my @created = mkpath( [$upload_dir], 0, 0777 );    ## no critic
+        ## no critic (ProhibitLeadingZeros)
+        # copy index.html to protect dir from Options Indexes
+        my $indexfile = File::Spec->catfile( $base_path, 'root', 'upload',
+            'index.html' );
         foreach my $dir (@created) {
             File::Copy::copy( $indexfile, $dir );
         }
     }
 
     my $target
-        = File::Spec->catfile( $base_path, 'root', 'upload', $directory_1, $directory_2,
-        $basename );
+        = File::Spec->catfile( $base_path, 'root', 'upload', $directory_1,
+        $directory_2, $basename );
 
     # rename if exist
     if ( -e $target ) {
         my $random_filename;
         while ( -e $target ) {
             $random_filename = generate_random_word(15) . ".$filetype";
-            $target = File::Spec->catfile( $base_path, 'root', 'upload', $directory_1,
-                $directory_2, $random_filename );
+            $target = File::Spec->catfile( $base_path, 'root', 'upload',
+                $directory_1, $directory_2, $random_filename );
         }
         $upload_rs->update( { filename => $random_filename } );
     }
@@ -166,7 +170,8 @@ sub change_for_forum {
     my $from_id = $info->{form_id} or return 0;
     my $to_id   = $info->{to_id}   or return 0;
 
-    $self->search( { forum_id => $from_id, } )->update( { forum_id => $to_id, } );
+    $self->search( { forum_id => $from_id, } )
+        ->update( { forum_id => $to_id, } );
 }
 
 1;
