@@ -6,7 +6,7 @@ use warnings;
 use Foorum::Version; our $VERSION = $Foorum::VERSION;
 
 use YAML::XS qw/LoadFile/;    # config
-use TheSchwartz::Simple;      # theschwartz
+use MooseX::TheSchwartz;      # theschwartz
 use DBI;
 use Template;                 # template
 use Template::Stash::XS;
@@ -25,6 +25,9 @@ use Cwd qw/abs_path/;
 my ( undef, $path ) = File::Spec->splitpath(__FILE__);
 $path = abs_path($path);
 
+# XXX? since make test copy files to blib
+$path =~ s/[\\\/]blib($|\\|\/)/$1/isg;
+
 sub base_path {
     return $base_path if ($base_path);
     $base_path = abs_path( File::Spec->catdir( $path, '..', '..' ) );
@@ -108,7 +111,7 @@ sub theschwartz {
         $config->{theschwartz_pwd}  || $config->{dsn_pwd},
         { PrintError => 1, RaiseError => 1 }
     );
-    $theschwartz = TheSchwartz::Simple->new( [$dbh] );
+    $theschwartz = MooseX::TheSchwartz->new( databases => [$dbh] );
 
     return $theschwartz;
 }
@@ -144,7 +147,7 @@ generally like $c->view('TT'), yet a bit different
 
 =item theschwartz
 
-TheSchwartz->new with correct database from $config
+L<MooseX::TheSchwartz> ->new with correct database from $config
 
 =back
 
